@@ -24,16 +24,7 @@
                                           environment = character(),
                                           stringsAsFactors = FALSE)
 .globals$suppress_warnings_handlers <- list()
-.globals$class_filters <- list(
-
-  function(classes) {
-    if ("python.builtin.BaseException" %in% classes) {
-      classes <- unique(c(classes, "error", "condition"))
-    }
-    classes
-  }
-
-)
+.globals$class_filters <- list()
 .globals$py_repl_active <- FALSE
 
 is_python_initialized <- function() {
@@ -86,13 +77,6 @@ ensure_python_initialized <- function(required_module = NULL) {
   if (is.function(callback))
     callback()
 
-  # set up a Python signal handler
-  signals <- import("rpytools.signals")
-  signals$initialize(py_interrupts_pending)
-
-  # register C-level interrupt handler
-  py_register_interrupt_handler()
-
   # call init hooks
   call_init_hooks()
 
