@@ -37,7 +37,6 @@ class M:
 })
 
 
-
 test_that("py_id() returns unique strings; #1216", {
   skip_if_no_python()
 
@@ -53,8 +52,6 @@ test_that("py_id() returns unique strings; #1216", {
 
 
 
-
-
 test_that("subclassed lists can be converted", {
   skip_if_no_python()
 
@@ -75,7 +72,14 @@ class List(Sequence, list):
     return len(self._storage)
 ")$List
 
-  expect_identical(List(1,2,3), list(1,2,3))
+  expect_contains(class(List(1,2,3)),
+                  c("__main__.List",
+                    "collections.abc.Sequence",
+                    "python.builtin.list",
+                    "python.builtin.object"))
+
+  py_bt_list <- import_builtins()$list
+  expect_identical(py_bt_list(List(1, 2, "3")), list(1, 2, "3"))
 
 })
 
@@ -96,13 +100,18 @@ assert isinstance(Dict({}), dict)
 
 ")$Dict
 
-  expect_identical(Dict(dict()), structure(list(), names = character(0)))
-  expect_identical(Dict(list("abc" = 1:3)), list("abc" = 1:3))
+  expect_contains(class(Dict(dict())),
+                  c("__main__.Dict",
+                    "python.builtin.ObjectProxy",
+                    "python.builtin.object"))
+
+  x <- list("abc" = 1:3)
+  py_bt_dict <- import_builtins()$dict
+  expect_identical(py_bt_dict(Dict(x)), x)
 
 })
 
 
-
 test_that("capsules can be freed by other threads", {
   skip_if_no_python()
 
@@ -141,3 +150,49 @@ def free_py_capsule_on_other_thread():
   expect_true(e_finalized)
 
 })
+
+
+test_that("py_to_r() generics are found from R functions called in Python", {
+  skip_if_no_python()
+
+
+  py_new_callback_caller <- py_run_string("
+def py_new_callback_caller(callback):
+    def callback_caller(*args, **kwargs):
+        callback(*args, **kwargs)
+    return callback_caller
+", local = TRUE)$py_new_callback_caller
+
+  r_callback <- function(x) {
+    expect_false(is_py_object(x))
+    expect_identical(x, list(a = 42))
+    x
+  }
+  callback_caller <- py_new_callback_caller(r_callback)
+
+
+  # simple type conversion handled in py_to_r_cpp
+  d <- list(a = 42)
+  callback_caller(d) # list() -> dict() -> list()
+
+  # conversion via package S3 method
+  od <- import("collections", convert = FALSE)$OrderedDict(d)
+  callback_caller(od)
+
+  # conversion via user S3 method
+  # ideally we would test by just defining `py_to_r.__main__.MyFoo` in the calling
+  # env like this:
+  #   (function() {
+  #     py_to_r.__main__.MyFoo <- function(x) list(a = 42)
+  #     callback_caller(new_MyFoo())
+  #   })()
+  #
+  # unfortunately, our ability to infer the userenv needs a little work.
+  # we register the S3 method directly as an alternative.
+  new_MyFoo <- py_eval("type('MyFoo', (), {})")
+  registerS3method("py_to_r", "__main__.MyFoo", function(x) list(a = 42),
+                   asNamespace("reticulate"))
+  new_MyFoo <- py_eval("type('MyFoo', (), {})")
+  callback_caller(new_MyFoo())
+
+})
